@@ -36,7 +36,7 @@ class GCPCredentialsManager:
     def get_credentials(self, as_dict=False):
         """Get the Google OAUTH2 service account credentials.
 
-        :param bool as_dict: if `True`, return the credentials as a dictionary
+        :param bool as_dict: if `True`, get the credentials as a dictionary
         :return dict|google.auth.service_account.Credentials|None:
         """
         if self.service_account_json is None:
@@ -52,7 +52,7 @@ class GCPCredentialsManager:
     def _get_credentials_from_file(self, as_dict=False):
         """Get the credentials from the JSON file whose path is specified in the environment variable's value.
 
-        :param bool as_dict: if `True`, return the credentials as a dictionary
+        :param bool as_dict: if `True`, get the credentials as a dictionary
         :return dict|google.auth.service_account.Credentials:
         """
         with open(self.service_account_json) as f:
@@ -68,7 +68,7 @@ class GCPCredentialsManager:
     def _get_credentials_from_string(self, as_dict=False):
         """Get the credentials directly from the JSON string specified in the environment variable's value.
 
-        :param bool as_dict: if `True`, return the credentials as a dictionary
+        :param bool as_dict: if `True`, get the credentials as a dictionary
         :return dict|google.auth.service_account.Credentials:
         """
         credentials = json.loads(self.service_account_json)
