@@ -1,7 +1,9 @@
 import json
 import logging
 
+import twined.exceptions
 from octue.definitions import OUTPUT_STRANDS
+from octue.exceptions import InvalidMonitorMessage
 from octue.mixins import Hashable, Identifiable, Labelable, Loggable, Serialisable, Taggable
 from octue.resources.manifest import Manifest
 from octue.utils.encoders import OctueJSONEncoder
@@ -40,7 +42,8 @@ class Analysis(Identifiable, Loggable, Serialisable, Labelable, Taggable):
     Analyses are instantiated at the top level of your app/service/twin code and you can import the instantiated
     object from there (see the templates for examples)
 
-    :param twined.Twine twine: Twine instance or json source
+    :param twined.Twine|str twine: Twine instance or json source
+    :param callable|None handle_monitor_message: a function that sends monitor messages to the parent that requested the analysis
     :param any configuration_values: see Runner.run() for definition
     :param octue.resources.manifest.Manifest configuration_manifest: see Runner.run() for definition
     :param any input_values: see Runner.run() for definition
@@ -54,12 +57,14 @@ class Analysis(Identifiable, Loggable, Serialisable, Labelable, Taggable):
     :return None:
     """
 
-    def __init__(self, twine, skip_checks=False, **kwargs):
+    def __init__(self, twine, handle_monitor_message=None, skip_checks=False, **kwargs):
         if isinstance(twine, Twine):
             self.twine = twine
         else:
             self.twine = Twine(source=twine)
 
+        self._handle_monitor_message = handle_monitor_message
+
         strand_kwargs = {name: kwargs.pop(name, None) for name in ALL_STRANDS}
 
         # Values strands.
@@ -82,12 +87,28 @@ class Analysis(Identifiable, Loggable, Serialisable, Labelable, Taggable):
 
         super().__init__(**kwargs)
 
+    def send_monitor_message(self, data):
+        """Send a monitor message to the parent that requested the analysis.
+
+        :param any data: any JSON-compatible data structure
+        :return None:
+        """
+        try:
+            self.twine.validate_monitor_message(source=data)
+        except twined.exceptions.InvalidValuesContents as e:
+            raise InvalidMonitorMessage(e)
+
+        if self._handle_monitor_message is None:
+            module_logger.warning("Attempted to send a monitor message but no handler is specified.")
+            return
+
+        self._handle_monitor_message(data)
+
     def finalise(self, output_dir=None, save_locally=False, upload_to_cloud=False, project_name=None, bucket_name=None):
         """Validate and serialise the output values and manifest, optionally writing them to files and/or the manifest
         to the cloud.
 
-        :param str output_dir: path-like pointing to directory where the outputs should be saved to file (if None, files
-            are not written)
+        :param str output_dir: path-like pointing to directory where the outputs should be saved to file (if None, files are not written)
         :param bool save_locally:
         :param bool upload_to_cloud:
         :param str project_name:
