@@ -5,6 +5,7 @@ import os
 import tempfile
 from urllib.parse import urlparse
 import google.api_core.exceptions
+import h5py
 import pkg_resources
 from google_crc32c import Checksum
 
@@ -258,6 +259,10 @@ class Datafile(Labelable, Taggable, Serialisable, Pathable, Loggable, Identifiab
 
     @property
     def name(self):
+        """Get the name of the datafile.
+
+        :return str:
+        """
         return self._name or str(os.path.split(self.path)[-1])
 
     @property
@@ -320,6 +325,10 @@ class Datafile(Labelable, Taggable, Serialisable, Pathable, Loggable, Identifiab
 
     @property
     def timestamp(self):
+        """Get the timestamp of the datafile.
+
+        :return float:
+        """
         return self._timestamp
 
     @timestamp.setter
@@ -368,6 +377,10 @@ class Datafile(Labelable, Taggable, Serialisable, Pathable, Loggable, Identifiab
 
     @property
     def size_bytes(self):
+        """Get the size of the datafile in bytes.
+
+        :return float:
+        """
         if self._path_is_in_google_cloud_storage:
             return self._cloud_metadata.get("size")
 
@@ -375,7 +388,7 @@ class Datafile(Labelable, Taggable, Serialisable, Pathable, Loggable, Identifiab
 
     @property
     def exists_in_cloud(self):
-        """Does the file exist in the cloud?
+        """Return `True` if the file exists in the cloud.
 
         :return bool:
         """
@@ -383,7 +396,7 @@ class Datafile(Labelable, Taggable, Serialisable, Pathable, Loggable, Identifiab
 
     @property
     def exists_locally(self):
-        """Does the file exist locally?
+        """Return `True` if the file exists locally.
 
         :return bool:
         """
@@ -590,7 +603,10 @@ class Datafile(Labelable, Taggable, Serialisable, Pathable, Loggable, Identifiab
             raise FileNotFoundException(f"No file found at {self.absolute_path}")
 
     def exists(self):
-        """Returns true if the datafile exists on the current system, false otherwise"""
+        """Return `True` if the datafile exists on the current system.
+
+        :return bool:
+        """
         return isfile(self.absolute_path)
 
     @property
@@ -665,7 +681,11 @@ class _DatafileContextManager:
         if "w" in self.mode:
             os.makedirs(os.path.split(self.datafile.local_path)[0], exist_ok=True)
 
-        self._fp = open(self.datafile.local_path, self.mode, **self.kwargs)
+        if self.datafile.extension == "hdf5":
+            self._fp = h5py.File(self.datafile.local_path, self.mode, **self.kwargs)
+        else:
+            self._fp = open(self.datafile.local_path, self.mode, **self.kwargs)
+
         return self._fp
 
     def __exit__(self, *args):
