@@ -5,6 +5,7 @@ import tempfile
 import uuid
 from datetime import datetime, timezone
 from unittest.mock import patch
+import h5py
 
 from octue import exceptions
 from octue.cloud import storage
@@ -23,11 +24,19 @@ class MyPathable(Pathable, MixinBase):
 
 class DatafileTestCase(BaseTestCase):
     def setUp(self):
+        """Set up the test class by adding an example `path_from` and `path` to it.
+
+        :return None:
+        """
         super().setUp()
         self.path_from = MyPathable(path=os.path.join(self.data_path, "basic_files", "configuration", "test-dataset"))
         self.path = os.path.join("path-within-dataset", "a_test_file.csv")
 
     def create_valid_datafile(self):
+        """Create a datafile with its `path_from` and `path` attributes set to valid values.
+
+        :return octue.resources.datafile.Datafile:
+        """
         return Datafile(path_from=self.path_from, path=self.path, skip_checks=False)
 
     def create_datafile_in_cloud(
@@ -99,12 +108,14 @@ class DatafileTestCase(BaseTestCase):
             Datafile(path="a_path") > "hello"
 
     def test_checks_fail_when_file_doesnt_exist(self):
+        """Test that the checks fail if the file used to instantiate the datafile doesn't exist."""
         path = "not_a_real_file.csv"
         with self.assertRaises(exceptions.FileNotFoundException) as error:
             Datafile(path=path, skip_checks=False)
         self.assertIn("No file found at", error.exception.args[0])
 
     def test_conflicting_extension_fails_check(self):
+        """Test that a conflicting extension parameter and extension on the file causes checks to fail."""
         with self.assertRaises(exceptions.InvalidInputException) as error:
             Datafile(path_from=self.path_from, path=self.path, skip_checks=False, extension="notcsv")
 
@@ -130,7 +141,7 @@ class DatafileTestCase(BaseTestCase):
             df._last_modified = 1000000000.5771205
 
     def test_repr(self):
-        """ Test that Datafiles are represented as expected. """
+        """Test that Datafiles are represented as expected."""
         self.assertEqual(repr(self.create_valid_datafile()), "<Datafile('a_test_file.csv')>")
 
     def test_serialisable(self):
@@ -743,3 +754,45 @@ class DatafileTestCase(BaseTestCase):
 
         downloaded_datafile = Datafile(project_name="blah", path=f"gs://{TEST_BUCKET_NAME}/name with spaces.txt")
         self.assertEqual(downloaded_datafile.name, "name with spaces.txt")
+
+    def test_creating_new_hdf5_datafile(self):
+        """Test that a new HDF5 datafile can be created and written to."""
+        with tempfile.TemporaryDirectory() as temporary_directory:
+            datafile = Datafile(path=os.path.join(temporary_directory, "my-file.hdf5"))
+
+            with datafile.open("w") as f:
+                f["dataset"] = range(10)
+
+            with h5py.File(datafile.local_path) as f:
+                self.assertEqual(list(f["dataset"]), list(range(10)))
+
+    def test_creating_datafile_from_existing_hdf5_file(self):
+        """Test that a datafile can be created from an existing HDF5 file."""
+        with tempfile.TemporaryDirectory() as temporary_directory:
+            path = os.path.join(temporary_directory, "my-file.hdf5")
+
+            with h5py.File(path, "w") as f:
+                f["dataset"] = range(10)
+
+            with Datafile(path=path) as (datafile, f):
+                self.assertEqual(list(f["dataset"]), list(range(10)))
+
+    def test_uploading_hdf5_datafile_to_cloud(self):
+        """Test that an HDF5 file can be uploaded to the cloud."""
+        with tempfile.TemporaryDirectory() as temporary_directory:
+            datafile = Datafile(path=os.path.join(temporary_directory, "my-file.hdf5"))
+
+            with datafile.open("w") as f:
+                f["dataset"] = range(10)
+
+            datafile.to_cloud(project_name=TEST_PROJECT_NAME, cloud_path=f"gs://{TEST_BUCKET_NAME}/my-file.hdf5")
+
+            download_path = os.path.join(temporary_directory, "downloaded-file.hdf5")
+
+            GoogleCloudStorageClient(project_name=TEST_PROJECT_NAME).download_to_file(
+                local_path=download_path,
+                cloud_path=datafile.cloud_path,
+            )
+
+            with h5py.File(download_path) as f:
+                self.assertEqual(list(f["dataset"]), list(range(10)))
